function wc_generate_distance_rule_conditions_row( size, group, row, isFirstTable = false ) {
	const removeButton = ! isFirstTable ? '<a href="#" class="remove_condition_row dashicons dashicons-no">&nbsp;</a>' : '';

	return `
	<tr class="distance_rule_group distance_rule_group_${ group } distance_rule_group_${ group }_row_${ row }" data-group="${ group }">
		<td>
			<select name="${ wc_distance_rate_params.id }_conditions[${ size }][${ group }][${ row }][condition]" class="wc-shipping-distance-rate-condition">
				<option value="distance">${ wc_distance_rate_params.i18n.distance }</option>
				<option value="time">${ wc_distance_rate_params.i18n.total_travel_time }</option>
				<option value="weight">${ wc_distance_rate_params.i18n.weight }</option>
				<option value="total">${ wc_distance_rate_params.i18n.order_total }</option>
				<option value="quantity">${ wc_distance_rate_params.i18n.quantity }</option>
			</select>
		</td>
		<td><input type="text" name="${ wc_distance_rate_params.id }_conditions[${ size }][${ group }][${ row }][min]" size="4" class="wc-shipping-distance-rate-min wc_input_price" /></td>
		<td><input type="text" name="${ wc_distance_rate_params.id }_conditions[${ size }][${ group }][${ row }][max]" size="4" class="wc-shipping-distance-rate-max wc_input_price" /></td>
		<td><button class="add_condition_row button">${ wc_distance_rate_params.i18n.and }</button><span class="add_condition_text">${ wc_distance_rate_params.i18n.and }</span></td>
		<td>${ removeButton }</td>
	</tr>`;
}

function wc_generate_distance_or_text() {
	return `
	<tr class="distance_or_text">
		<td colspan="3">${ wc_distance_rate_params.i18n.or }</td>
	</tr>`;
}

function wc_generate_distance_rule_conditions_table( size, group, row, isFirstRow = true, isFirstTable = false ) {
	let rows = wc_generate_distance_rule_conditions_row( size, group, row, isFirstTable );
	if ( ! isFirstRow ) rows = wc_generate_distance_or_text() + rows;

	return `
	<table class="distance_rule_conditions">
		<tbody>${ rows }</tbody>
	</table>`;
}

function wc_generate_distance_rule_conditions_final_table( size, group, row ) {
	const table = wc_generate_distance_rule_conditions_table( size, group, row, true, true );
	return `${ table }
	<table class="distance_rule_add_table_button">
		${ wc_generate_distance_or_text() }
		<tr>
			<td colspan="3" class="distance_or_button"><button class="or_condition_row button">${ wc_distance_rate_params.i18n.add_rule_group }</button></td>
		</tr>
	</table>`;
}

function wc_event_add_rule_button_on_click( evt ) {
	evt.preventDefault();

	const parentDr     = jQuery( this ).closest( '.distance_rule' );
	const parentTable  = jQuery( this ).closest( '.distance_rule_add_table_button' );
	const parentColumn = parentTable.closest( '.table-condition-column' );
	const tableCount   = parentColumn.find( '.distance_rule_conditions' ).length;
	const rowNumber    = parentDr.data( 'row' );

	parentTable.before( wc_generate_distance_rule_conditions_table( rowNumber, tableCount, 0, false, false ) );

	const lastTable = parentColumn.find( '.distance_rule_conditions' ).last();
	lastTable.find( '.add_condition_row.button' ).on( 'click', wc_event_add_row_button_on_click );
	lastTable.find( '.remove_condition_row' ).on( 'click', wc_event_remove_row_button_on_click );
}

function wc_event_add_row_button_on_click( evt ) {
	evt.preventDefault();

	const parentTable = jQuery( this ).closest( '.distance_rule_conditions' );
	const parentDr    = parentTable.closest( '.distance_rule' );
	const group       = jQuery( this ).closest( 'tr' ).data( 'group' );
	const rowLength   = parentTable.find( `.distance_rule_group_${ group }` ).length;
	const rowNumber   = parentDr.data( 'row' );

	const newRow = wc_generate_distance_rule_conditions_row( rowNumber, group, rowLength, false );
	parentTable.find( 'tbody' ).append( newRow );

	const lastRow = parentTable.find( 'tr' ).last();
	lastRow.find( '.add_condition_row.button' ).on( 'click', wc_event_add_row_button_on_click );
	lastRow.find( '.remove_condition_row' ).on( 'click', wc_event_remove_row_button_on_click );
}

function wc_event_remove_row_button_on_click( evt ) {
	evt.preventDefault();

	const parentTable = jQuery( this ).closest( '.distance_rule_conditions' );
	if ( parentTable.find( 'tr.distance_rule_group' ).length === 1 ) {
		parentTable.remove();
	} else {
		jQuery( this ).closest( 'tr' ).remove();
	}
}

function wc_event_abort_checkbox_change( evt ) {
	evt.preventDefault();
	const isChecked = jQuery( this ).is( ':checked' );
	jQuery( this ).closest( 'tr' ).toggleClass( 'abort-active', isChecked );
}

jQuery( () => {
	const rootElement     = jQuery( `#${ wc_distance_rate_params.id }_rules` );
	const priceInputClass = 'wc_input_price';

	rootElement.find( '.or_condition_row.button' ).on( 'click', wc_event_add_rule_button_on_click );
	rootElement.find( '.add_condition_row.button' ).on( 'click', wc_event_add_row_button_on_click );
	rootElement.find( '.remove_condition_row' ).on( 'click', wc_event_remove_row_button_on_click );
	rootElement.find( '.col-abort input' ).on( 'change', wc_event_abort_checkbox_change );

	let isAdvModeActivated = rootElement.find( 'tr.distance_rule' ).toArray().some( el => jQuery( el ).find( '.distance_rule_group' ).length > 1 );
	if ( isAdvModeActivated ) rootElement.find( '.shippingrows' ).addClass( 'advanced_mode' );

	rootElement.on( 'click', 'a.add', function () {
		const size          = rootElement.find( 'tbody .distance_rule' ).length;
		const newTable      = wc_generate_distance_rule_conditions_final_table( size, 0, 0 );
		const distanceRates = rootElement.find( 'table.shippingrows tbody.distance_rates' );

		const newRow = jQuery( `
			<tr class="distance_rule" data-row="${ size }">
				<th class="check-column"><input type="checkbox" name="select" /></th>
				<td colspan="3" class="col-condition table-condition-column">${ newTable }</td>
				<td class="col-cost"><input type="text" name="${ wc_distance_rate_params.id }_cost[${ size }]" size="4" class="wc_input_price" /></td>
				<td class="col-cost-unit"><input type="text" name="${ wc_distance_rate_params.id }_cost_unit[${ size }]" size="4" class="wc_input_price" /></td>
				<td class="col-unit">
					<select name="${ wc_distance_rate_params.id }_unit[${ size }]" class="wc-shipping-distance-rate-unit">
						<option value="distance">${ wc_distance_rate_params.i18n.distance }</option>
						<option value="time">${ wc_distance_rate_params.i18n.travel_time }</option>
					</select>
				</td>
				<td class="col-per-qty"><input type="checkbox" name="${ wc_distance_rate_params.id }_per_qty[${ size }]" /></td>
				<td class="col-fee"><input type="text" name="${ wc_distance_rate_params.id }_fee[${ size }]" size="4" class="wc_input_price" /></td>
				<td class="col-break"><input type="checkbox" name="${ wc_distance_rate_params.id }_break[${ size }]" /></td>
				<td colspan="6" class="col-abort-text"><input type="text" placeholder="${ wc_distance_rate_params.i18n.abort_text }" name="${ wc_distance_rate_params.id }_abort_text[${ size }]" /></td>
				<td class="col-abort"><input type="checkbox" name="${ wc_distance_rate_params.id }_abort[${ size }]" /></td>
			</tr>` );

		newRow.appendTo( distanceRates );
		newRow.find( '.or_condition_row.button' ).on( 'click', wc_event_add_rule_button_on_click );
		newRow.find( '.add_condition_row.button' ).on( 'click', wc_event_add_row_button_on_click );
		newRow.find( '.remove_condition_row' ).on( 'click', wc_event_remove_row_button_on_click );
		newRow.find( '.col-abort input' ).on( 'change', wc_event_abort_checkbox_change );

		jQuery( '.wc-shipping-distance-rate-condition' ).trigger( 'change' );
		return false;
	} );

	rootElement.on( 'click', 'a.remove', function () {
		if ( confirm( wc_distance_rate_params.i18n.del_selected_rule ) ) {
			rootElement.find( 'table tbody tr th.check-column input:checked' ).each( ( _, el ) => jQuery( el ).closest( 'tr' ).remove() );
		}
		return false;
	} );

	rootElement.on( 'click', 'a.advanced_mode', function () {
		rootElement.find( '.shippingrows' ).toggleClass( 'advanced_mode' );
		return false;
	} );

	rootElement.on( 'change', '.wc-shipping-distance-rate-condition', function () {
		const conditionType = jQuery( this ).val();
		const isPriceType   = conditionType === 'total';
		const minField      = jQuery( this ).parents( 'tr.distance_rule' ).find( '.wc-shipping-distance-rate-min' );
		const maxField      = jQuery( this ).parents( 'tr.distance_rule' ).find( '.wc-shipping-distance-rate-max' );

		minField.toggleClass( priceInputClass, isPriceType );
		maxField.toggleClass( priceInputClass, isPriceType );
	} );
} );
